@@ -2,7 +2,12 @@ test_that("framework-ffa works on KOOTENAI RIVER (08NH021) with no splits/struct
 
 	df <- data_local("CAN-08NH021.csv")
 
-	results <- framework_ffa(df$max, df$year)
+	results <- framework_ffa(
+		df$max,
+		df$year,
+		generate_report = FALSE
+	)
+
 	expect_true(is.list(results))
 	expect_equal(length(results$submodule_results), 4)
 
@@ -17,7 +22,14 @@ test_that("framework-ffa works on KOOTENAI RIVER (08NH021) with splits/structure
 
 	df <- data_local("CAN-08NH021.csv")
 
-	results <- framework_ffa(df$max, df$year, 1972, list(S10, S10))
+	results <- framework_ffa(
+		df$max,
+		df$year,
+		1972, 
+		list(S10, S10), 
+		generate_report = FALSE
+	)
+
 	expect_true(is.list(results))
 	expect_equal(length(results$submodule_results), 8)
 
